==> tfds-nightly-3.2.1.dev202009250215.tar.gz: tfds-nightly-3.2.1.dev202009250215/tensorflow_datasets/audio/__init__.py <==
# coding=utf-8
# Copyright 2020 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Audio datasets."""

from tensorflow_datasets.audio.commonvoice import CommonVoice
from tensorflow_datasets.audio.commonvoice import CommonVoiceConfig
from tensorflow_datasets.audio.crema_d import CremaD
from tensorflow_datasets.audio.dementiabank import Dementiabank
from tensorflow_datasets.audio.fuss import Fuss
from tensorflow_datasets.audio.groove import Groove
from tensorflow_datasets.audio.gtzan import GTZAN
from tensorflow_datasets.audio.gtzan_music_speech import GTZANMusicSpeech
from tensorflow_datasets.audio.librispeech import Librispeech
from tensorflow_datasets.audio.librispeech import LibrispeechConfig
from tensorflow_datasets.audio.libritts import Libritts
from tensorflow_datasets.audio.ljspeech import Ljspeech
from tensorflow_datasets.audio.nsynth import Nsynth
from tensorflow_datasets.audio.savee import Savee
from tensorflow_datasets.audio.speech_commands import SpeechCommands
from tensorflow_datasets.audio.spoken_digit import SpokenDigit
from tensorflow_datasets.audio.tedlium import Tedlium
from tensorflow_datasets.audio.vctk import Vctk
from tensorflow_datasets.audio.voxceleb import Voxceleb
from tensorflow_datasets.audio.voxforge import Voxforge
from tensorflow_datasets.audio.yesno import YesNo

==> tfds-nightly-4.9.6.dev202409040044.tar.gz: tfds-nightly-4.9.6.dev202409040044/tensorflow_datasets/audio/__init__.py <==
# coding=utf-8
# Copyright 2024 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Audio datasets."""

from tensorflow_datasets.audio.accentdb import Accentdb
from tensorflow_datasets.audio.commonvoice import CommonVoice
from tensorflow_datasets.audio.commonvoice import CommonVoiceConfig
from tensorflow_datasets.audio.crema_d import CremaD
from tensorflow_datasets.audio.dementiabank import Dementiabank
from tensorflow_datasets.audio.fuss import Fuss
from tensorflow_datasets.audio.groove import Groove
from tensorflow_datasets.audio.gtzan import GTZAN
from tensorflow_datasets.audio.gtzan_music_speech import GTZANMusicSpeech
from tensorflow_datasets.audio.librispeech import Librispeech
from tensorflow_datasets.audio.libritts import Libritts
from tensorflow_datasets.audio.ljspeech import Ljspeech
from tensorflow_datasets.audio.nsynth import Nsynth
from tensorflow_datasets.audio.savee import Savee
from tensorflow_datasets.audio.speech_commands import SpeechCommands
from tensorflow_datasets.audio.spoken_digit import SpokenDigit
from tensorflow_datasets.audio.tedlium import Tedlium
from tensorflow_datasets.audio.userlibri_audio_data import UserLibriAudio
from tensorflow_datasets.audio.vctk import Vctk
from tensorflow_datasets.audio.voxceleb import Voxceleb
from tensorflow_datasets.audio.voxforge import Voxforge
from tensorflow_datasets.audio.xtreme_s import XtremeS
from tensorflow_datasets.audio.yesno import YesNo
